Download the latest Legal Entity Identifier (LEI) mapping data from the Global Legal Entity Identifier Foundation (GLEIF).
Usage
lei_mapping(type = c("isin", "bic", "mic", "oc"))Value
A data.frame() with the lei and the corresponding mapping.
Download the latest Legal Entity Identifier (LEI) mapping data from the Global Legal Entity Identifier Foundation (GLEIF).
lei_mapping(type = c("isin", "bic", "mic", "oc"))A data.frame() with the lei and the corresponding mapping.